==> mongodb-5.0.32.gh.tar.gz: mongo-r5.0.32/src/mongo/transport/transport_layer_egress_init.cpp <==
/**
 *    Copyright (C) 2018-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#include "mongo/platform/basic.h"

#include "mongo/base/init.h"
#include "mongo/db/service_context.h"
#include "mongo/transport/transport_layer_asio.h"

#include <iostream>

namespace mongo {
namespace {
// Linking with this file will configure an egress-only TransportLayer on all new ServiceContexts.
// Use this for unit/integration tests that require only egress networking.

ServiceContext::ConstructorActionRegisterer registerEgressTransportLayer{
    "ConfigureEgressTransportLayer", [](ServiceContext* sc) {
        invariant(!sc->getTransportLayer());
        transport::TransportLayerASIO::Options opts;
        opts.mode = transport::TransportLayerASIO::Options::kEgress;
        sc->setTransportLayer(std::make_unique<transport::TransportLayerASIO>(opts, nullptr));
        uassertStatusOK(sc->getTransportLayer()->setup());
        uassertStatusOK(sc->getTransportLayer()->start());
    }};

}  // namespace
}  // namespace mongo

==> mongodb-7.0.23.gh.tar.gz: mongo-r7.0.23/src/mongo/transport/transport_layer_egress_init.cpp <==
/**
 *    Copyright (C) 2018-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#include "mongo/platform/basic.h"

#include "mongo/base/init.h"
#include "mongo/db/service_context.h"
#include "mongo/transport/asio/asio_transport_layer.h"

#include <iostream>

namespace mongo {
namespace {
// Linking with this file will configure an egress-only TransportLayer on all new ServiceContexts.
// Use this for unit/integration tests that require only egress networking.

ServiceContext::ConstructorActionRegisterer registerEgressTransportLayer{
    "ConfigureEgressTransportLayer", [](ServiceContext* sc) {
        invariant(!sc->getTransportLayer());
        transport::AsioTransportLayer::Options opts;
        opts.mode = transport::AsioTransportLayer::Options::kEgress;
        sc->setTransportLayer(std::make_unique<transport::AsioTransportLayer>(opts, nullptr));
        uassertStatusOK(sc->getTransportLayer()->setup());
        uassertStatusOK(sc->getTransportLayer()->start());
    }};

}  // namespace
}  // namespace mongo
